# remirepo spec file for php-pecl-event
# with SCL compatibility, from:
#
# Fedora spec file for php-pecl-event
#
# Copyright (c) 2013-2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

# we don't want -z defs linker flag
%undefine _strict_symbol_defs_build

%if 0%{?scl:1}
%global sub_prefix   %{scl_prefix}
%scl_package         php-pecl-event
%else
%global _root_prefix %{_prefix}
%endif

%bcond_without      tests

%global pecl_name   event
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%if "%{php_version}" < "5.6"
# After sockets.so
%global ini_name  z-%{pecl_name}.ini
%else
# After 20-sockets.so
%global ini_name  40-%{pecl_name}.ini
%endif
%global upstream_version 3.0.4
#global upstream_prever  RC3
#global upstream_postver r1

Summary:       Provides interface to libevent library
Name:          %{?sub_prefix}php-pecl-%{pecl_name}
Version:       %{upstream_version}%{?upstream_prever:~%{upstream_prever}}%{?upstream_postver:+%{upstream_postver}}
Release:       1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:       PHP
URL:           https://pecl.php.net/package/event
Source0:       https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}%{?upstream_postver}.tgz

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel
BuildRequires: %{?scl_prefix}php-pear
#BuildRequires: gdb
#BuildRequires: php-debuginfo

BuildRequires:  pkgconfig(libevent) >= 2
%global        _event_prefix %{_root_prefix}

BuildRequires: openssl-devel
BuildRequires: pkgconfig

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
Requires:      %{?scl_prefix}php-sockets%{?_isa}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:      %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:      %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%endif

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
%if "%{php_version}" > "7.3"
Obsoletes:      php73-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:      php74-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "8.0"
Obsoletes:      php80-pecl-%{pecl_name} <= %{version}
%endif
%endif


%description
This is an extension to efficiently schedule I/O, time and signal based
events using the best I/O notification mechanism available for specific
platform. This is a port of libevent to the PHP infrastructure.

Version 1.0.0 introduces:
* new OO API breaking backwards compatibility
* support of libevent 2+ including HTTP, DNS, OpenSSL and the event listener.

Documentation: http://php.net/event

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c 

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

mv %{pecl_name}-%{upstream_version}%{?upstream_prever}%{?upstream_postver} NTS

cd NTS
# Sanity check, really often broken
DIR=$(%{__php} -r 'echo "php" . PHP_MAJOR_VERSION;')
sed -e '/PHP_EVENT_VERSION/s/2.4.2/2.4.3/' -i $DIR/php_event.h

extver=$(sed -n '/#define PHP_EVENT_VERSION/{s/.* "//;s/".*$//;p}' $DIR/php_event.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}%{?upstream_postver}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}%{?upstream_postver}.
   exit 1
fi
cd ..

# duplicate for ZTS build
%if %{with_zts}
cp -pr NTS ZTS
%endif

# Drop in the bit of configuration
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension = %{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-event-libevent-dir=%{_event_prefix} \
    --with-libdir=%{_lib} \
    --with-event-core \
    --with-event-extra \
    --with-event-openssl \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-event-libevent-dir=%{_event_prefix} \
    --with-libdir=%{_lib} \
    --with-event-core \
    --with-event-extra \
    --with-event-openssl \
    --with-event-pthreads \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# use z-event.ini to ensure event.so load "after" sockets.so
: Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
: Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

: Install the package XML file
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

: Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
%if "%{php_version}" < "7"
rm ?TS/tests/61-issue.phpt
rm ?TS/tests/10-event-data-dtor.phpt
rm ?TS/tests/27-event-util-create-socket.phpt
%endif

if [ -f %{php_extdir}/sockets.so ]; then
  OPTS="-d extension=sockets.so"
fi

: Minimal load test for NTS extension
%{__php} --no-php-ini $OPTS  \
    --define extension=NTS/modules/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini $OPTS  \
    --define extension=ZTS/modules/%{pecl_name}.so \
    --modules | grep %{pecl_name}
%endif

%if %{with tests}
cd NTS
: Upstream test suite for NTS extension
SKIP_ONLINE_TESTS=1 \
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n $OPTS -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff

%if %{with_zts}
cd ../ZTS
: Upstream test suite for ZTS extension
SKIP_ONLINE_TESTS=1 \
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n $OPTS -d extension=$PWD/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license NTS/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Apr 20 2021 Remi Collet <remi@remirepo.net> - 3.0.4-1
- update to 3.0.4

* Sat Mar 27 2021 Remi Collet <remi@remirepo.net> - 3.0.3-1
- update to 3.0.3

* Tue Feb 16 2021 Remi Collet <remi@remirepo.net> - 3.0.2+r1-1
- update to 3.0.2r1 (stable)

* Mon Dec  7 2020 Remi Collet <remi@remirepo.net> - 3.0.2-1
- update to 3.0.2

* Wed Dec  2 2020 Remi Collet <remi@remirepo.net> - 3.0.1-1
- update to 3.0.1 (no change)

* Wed Oct 28 2020 Remi Collet <remi@remirepo.net> - 3.0.0-1
- update to 3.0.0 (beta)

* Mon Sep  7 2020 Remi Collet <remi@remirepo.net> - 2.5.7-1
- update to 2.5.7

* Wed May 20 2020 Remi Collet <remi@remirepo.net> - 2.5.6-1
- update to 2.5.6

* Tue May 12 2020 Remi Collet <remi@remirepo.net> - 2.5.5-1
- update to 2.5.5

* Sun Feb 23 2020 Remi Collet <remi@remirepo.net> - 2.5.4-1
- update to 2.5.4

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 2.5.3-3
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 2.5.3-2
- rebuild for 7.4.0beta1

* Mon Jun 17 2019 Remi Collet <remi@remirepo.net> - 2.5.3-1
- update to 2.5.3

* Wed Jun  5 2019 Remi Collet <remi@remirepo.net> - 2.5.2-1
- update to 2.5.2

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 2.5.1-2
- rebuild

* Mon May 27 2019 Remi Collet <remi@remirepo.net> - 2.5.1-1
- update to 2.5.1

* Mon Apr 29 2019 Remi Collet <remi@remirepo.net> - 2.5.0-1
- update to 2.5.0

* Fri Apr 19 2019 Remi Collet <remi@remirepo.net> - 2.4.4-1
- update to 2.4.4

* Mon Dec 10 2018 Remi Collet <remi@remirepo.net> - 2.4.3-1
- update to 2.4.3 (no change)

* Mon Nov 26 2018 Remi Collet <remi@remirepo.net> - 2.4.2-1
- update to 2.4.2

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 2.4.1-2
- rebuild for 7.3.0beta2 new ABI

* Sun Aug 12 2018 Remi Collet <remi@remirepo.net> - 2.4.1-1
- update to 2.4.1

* Mon Jul 23 2018 Remi Collet <remi@remirepo.net> - 2.4.0-1
- update to 2.4.0

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 2.4.0~RC3-2
- rebuld for 7.3.0alpha4 new ABI

* Thu May 24 2018 Remi Collet <remi@remirepo.net> - 2.4.0~RC3-1
- update to 2.4.0RC3

* Thu May 24 2018 Remi Collet <remi@remirepo.net> - 2.4.0~RC2-2
- test build

* Sun May 13 2018 Remi Collet <remi@remirepo.net> - 2.4.0~RC2-1
- update to 2.4.0RC2

* Mon Apr 23 2018 Remi Collet <remi@remirepo.net> - 2.4.0~RC1-1
- update to 2.4.0RC1

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 2.3.0-4
- rebuild for PHP 7.2.0beta1 new API

* Fri Jun 23 2017 Remi Collet <remi@remirepo.net> - 2.3.0-3
- ensure we use libevent2 on EL-6

* Mon Mar 27 2017 Remi Collet <remi@remirepo.net> - 2.3.0-2
- F26: rebuild with new libevent and test suite fully enabled

* Sun Mar 26 2017 Remi Collet <remi@remirepo.net> - 2.3.0-1
- update to 2.3.0 (stable)

* Wed Feb 15 2017 Remi Collet <remi@fedoraproject.org> - 2.3.0-0.3.RC1
- ignore 2 failed tests, fix FTBFS

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 2.3.0-0.2.RC1
- rebuild with PHP 7.1.0 GA

* Fri Nov 11 2016 Remi Collet <remi@fedoraproject.org> - 2.3.0-0.1.RC1
- Update to 2.3.0RC1 (php 5 and 7, beta)

* Thu Nov 10 2016 Remi Collet <remi@fedoraproject.org> - 2.2.1-1
- Update to 2.2.1 (php 5 and 7, stable)

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 2.1.0-2
- rebuild for PHP 7.1 new API version

* Wed Jun 08 2016 Remi Collet <remi@fedoraproject.org> - 2.1.0-1
- Update to 2.1.0

* Fri Apr 22 2016 Remi Collet <remi@fedoraproject.org> - 2.0.4-1
- Update to 2.0.4

* Thu Apr 21 2016 Remi Collet <remi@fedoraproject.org> - 2.0.3-1
- Update to 2.0.3 (php 5 and 7, stable)

* Fri Apr 01 2016 Remi Collet <remi@fedoraproject.org> - 2.0.2-1
- Update to 2.0.2 (php 5 and 7, stable)

* Thu Mar 17 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-1
- Update to 2.0.1 (php 5 and 7, stable)

* Mon Feb 29 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-1
- Update to 2.0.0 (php 5 and 7, stable)

* Thu Feb 25 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-0.2.RC2
- Update to 2.0.0RC2 (php 5 and 7, beta)

* Sun Feb 21 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-0.1.RC1
- Update to 2.0.0RC1 (php 5 and 7, beta)

* Thu Feb 11 2016 Remi Collet <remi@fedoraproject.org> - 1.11.3-1
- Update to 1.11.3

* Sun Jun 21 2015 Remi Collet <remi@fedoraproject.org> - 1.11.1-2
- allow build against rh-php56 (as more-php56)
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 1.11.1-1.1
- Fedora 21 SCL mass rebuild

* Fri Nov 14 2014 Remi Collet <remi@fedoraproject.org> - 1.11.1-1
- Update to 1.11.1 (stable)
- no change, only our patch merged upstream

* Thu Nov 13 2014 Remi Collet <remi@fedoraproject.org> - 1.11.0-1
- Update to 1.11.0 (stable)
- don't provide test suite
- add patch for old openssl in EL-5
  https://bitbucket.org/osmanov/pecl-event/pull-request/10

* Mon Aug 25 2014 Remi Collet <rcollet@redhat.com> - 1.10.3-2
- improve SCL build

* Mon Aug 11 2014 Remi Collet <remi@fedoraproject.org> - 1.10.3-1
- Update to 1.10.3 (no change)

* Fri Jun 20 2014 Remi Collet <remi@fedoraproject.org> - 1.10.2-1
- Update to 1.10.2 (stable)

* Sun May 11 2014 Remi Collet <remi@fedoraproject.org> - 1.10.1-1
- Update to 1.10.1 (stable, no change)

* Sat May 10 2014 Remi Collet <remi@fedoraproject.org> - 1.10.0-1
- Update to 1.10.0 (stable)

* Wed Apr  9 2014 Remi Collet <remi@fedoraproject.org> - 1.9.1-3
- add numerical prefix to extension configuration file

* Sun Mar 23 2014 Remi Collet <remi@fedoraproject.org> - 1.9.1-2
- allow SCL build, with libevent from SCL when needed

* Sun Mar 23 2014 Remi Collet <remi@fedoraproject.org> - 1.9.1-1
- Update to 1.9.1 (stable)

* Sun Mar 23 2014 Remi Collet <remi@fedoraproject.org> - 1.9.0-2
- add patch for php 5.6
  https://bitbucket.org/osmanov/pecl-event/pull-request/7

* Fri Jan 17 2014 Remi Collet <remi@fedoraproject.org> - 1.9.0-1
- Update to 1.9.0 (stable)
- add option to disable tests during build
- adapt for SCL

* Sat Jan 11 2014 Remi Collet <remi@fedoraproject.org> - 1.8.1-2
- install doc in pecl doc_dir
- install tests in pecl test_dir
- open https://bitbucket.org/osmanov/pecl-event/pull-request/6

* Mon Oct 07 2013 Remi Collet <remi@fedoraproject.org> - 1.8.1-1
- Update to 1.8.1 (stable)
- drop patch merged upstream
- patch for https://bitbucket.org/osmanov/pecl-event/pull-request/4

* Sun Oct 06 2013 Remi Collet <remi@fedoraproject.org> - 1.8.0-1
- Update to 1.8.0
- patch for https://bitbucket.org/osmanov/pecl-event/pull-request/3

* Mon Sep 16 2013 Remi Collet <remi@fedoraproject.org> - 1.7.8-1
- Update to 1.7.8

* Sun Sep 08 2013 Remi Collet <remi@fedoraproject.org> - 1.7.6-1
- Update to 1.7.6

* Mon Aug 19 2013 Remi Collet <remi@fedoraproject.org> - 1.7.5-1
- Update to 1.7.5

* Sun Jul 28 2013 Remi Collet <remi@fedoraproject.org> - 1.7.2-1
- Update to 1.7.2

* Wed Jul 24 2013 Remi Collet <remi@fedoraproject.org> - 1.7.1-1
- Update to 1.7.1

* Thu Jul 18 2013 Remi Collet <remi@fedoraproject.org> - 1.7.0-1
- Update to 1.7.0

* Thu Jul 18 2013 Remi Collet <remi@fedoraproject.org> - 1.6.2-2
- missing requires php-sockets
- enable thread safety for ZTS extension

* Thu Jul 18 2013 Remi Collet <remi@fedoraproject.org> - 1.6.2-1
- Update to 1.6.2

* Sat Apr 20 2013 Remi Collet <remi@fedoraproject.org> - 1.6.1-1
- initial package, version 1.6.1
- upstream bugs:
  https://bugs.php.net/64678 missing License
  https://bugs.php.net/64679 buffer overflow
  https://bugs.php.net/64680 skip online test
